#!/bin/bash

#assure that the script is executed with administrative rights

val=`id -u`
if [ ! $val -eq "0" ]; then
	# not root, run sudo once to cache the authorization
	# for further sudo uses in this script
	# reset the sudo cached password timestamp
	sudo -k
	val=`sudo -p "Enter your password to perform administrative tasks: " id -u`
	val=${val:="-1"}
	if [ ! $val -eq "0" ]; then
		echo "Authentication failed."
		exit 1
	fi	
fi

val=`grep -c -E "^UserCode=" /etc/epp/options.ini`
if [ ! $val -ge "1" ]; then
	echo "My Endpoin Protector doesn't seem to be installed."
	exit 0
fi


read -d '' x17 <<"EOF"
eDE3PWAvdXNyL2Jpbi9ncmVwIC1FICJecHJvdGVjdD0iIC9wcml2YXRlL2V0Yy9l
cHAvb3B0aW9ucy5pbmkgMj4gL2Rldi9udWxsIHwgL3Vzci9iaW4vc2VkIC1FICdz
L15bXj1dKz0vL2cnYAppZiBbICIkeyN4MTd9IiAtZXEgMzIgXTsgdGhlbgogICAg
ICAgIHJlYWQgLXMgLXAgIlBsZWFzZSBlbnRlciB5b3VyIHBhc3N3b3JkIGZvciB1
bmluc3RhbGwgcHJvdGVjdGlvbjogIiBDSEFMTEVOR0UxNwogICAgICAgIC9iaW4v
ZWNobwogICAgICAgIENIQUxMRU5HRTE3PWAvYmluL2VjaG8gLW4gJHtDSEFMTEVO
R0UxN30gfCAvc2Jpbi9tZDVgCiAgICAgICAgaWYgWyAke0NIQUxMRU5HRTE3fSAh
PSAke3gxN30gXTsgdGhlbgogICAgICAgICAgICAgICAgL2Jpbi9lY2hvICJUaGUg
cGFzc3dvcmQgaXMgaW5jb3JyZWN0ISIKICAgICAgICAgICAgICAgIGV4aXQgMQog
ICAgICAgIGZpCmZpCgo=
EOF
eval "`echo "${x17}" | openssl enc -base64 -d`"

echo "Removing Endpoint Protector from your system ..."
val=`ps axc | grep -c EppClient`
if [ $val -ge "1" ]; then
	echo "Stopping the Endpoint Protector daemon ..."
	sudo /bin/launchctl unload /Library/LaunchDaemons/com.cososys.eppclient.launchdaemon.plist
    # old kind of daemon is running, try to stop it
	if [ -d "/Library/StartupItems/EppStartUp" ]; then	
		sudo /sbin/SystemStarter stop "Endpoint Protector"
	fi
	# wait for the client service to die, before proceeding with file deletions
	/bin/sleep 2 	
else
	echo "The Endpoint Protector daemon is not running."
fi

if [ -f "/Library/StartupItems/EppStartUp/EppClient" ]; then
	echo "Endpoint Protector daemon is installed ... removing."
	sudo rm /Library/StartupItems/EppStartUp/EppClient
fi

if [ -f "/Library/LaunchDaemons/com.cososys.eppclient.launchdaemon.plist" ]; then
	echo "Endpoint Protector launchd starter is installed ... removing."
	sudo rm /Library/LaunchDaemons/com.cososys.eppclient.launchdaemon.plist
else
    echo "The Endpoint Protector launchd starter is not installed."
fi


val=`kextstat | grep -c EPPDeviceController`
if [ $val -eq "1" ]; then
	echo "The kernel extension is loaded ... stopping."
    sudo kextunload /System/Library/Extensions/EPPDeviceController.kext	
else
	echo "The kernel extension is not loaded."
fi

val=`kextstat | grep -c EPPUsbHelper`
if [ $val -eq "1" ]; then
	echo "The EPPUsbHelper kernel extension is loaded ... stopping."
    sudo kextunload /System/Library/Extensions/EPPUsbHelper.kext	
else
	echo "The EPPUsbHelper kernel extension is not loaded."
fi

if [ -d "/System/Library/Extensions/EPPDeviceController.kext" ]; then
	echo "The kernel extension is installed ... removing."
    sudo rm -rf /System/Library/Extensions/EPPDeviceController.kext	
else
	echo "The kernel extension is not installed"
fi

val=`kextstat | grep -c eppkauth`
if [ $val -eq "1" ]; then
	echo "The eppkauth extension is loaded ... stopping."
    sudo kextunload /System/Library/Extensions/eppkauth.kext	
else
	echo "The eppkauth extension is not loaded."
fi

if [ -d "/System/Library/Extensions/eppkauth.kext" ]; then
	echo "The eppkauth extension is installed ... removing."
    sudo rm -rf /System/Library/Extensions/eppkauth.kext	
else
	echo "The eppkauth extension is not installed"
fi
if [ -d "/System/Library/Extensions/EPPUsbHelper.kext" ]; then
	echo "The EPPUsbHelper kernel extension is installed ... removing."
    sudo rm -rf /System/Library/Extensions/EPPUsbHelper.kext	
else
	echo "The EPPUsbHelper.kext kernel extension is not installed"
fi

if [ -d "/Library/StartupItems/EppStartUp" ]; then
	echo "Startup item installed ... removing."
	sudo rm -rf /Library/StartupItems/EppStartUp
else
	echo "Startup item is not installed."
fi

if [ -d "/Library/CoSoSys/EndpointProtector" ]; then
	echo "EndpointProtector folder is installed ... removing."
	sudo rm -rf /Library/CoSoSys/EndpointProtector
else
	echo "Startup item is not installed."
fi

# prune empty directories
find /Library -name CoSoSys -type d -empty -maxdepth 1 | xargs sudo rmdir

if [ -d "/private/etc/epp" ]; then
	echo "Configuration folder exists ... removing."
	sudo rm -rf /private/etc/epp
else
	echo "Configuration folder does not exist."
fi

#remove shadow files if any are still there
if [ -d "/private/var/tmp/epp" ]; then
	echo "Shadowing folder exists ... removing."
	sudo rm -rf /private/var/tmp/epp
else
	echo "Shadowing folder does not exist."
fi

#remove the widget
if [ -d "/Library/Widgets/Endpoint Protector.wdgt" ]; then
	echo "Dashboard widget is installed ... removing."
	sudo rm -rf "/Library/Widgets/Endpoint Protector.wdgt"
else
	if [ -d "/Library/Widgets/My Endpoint Protector.wdgt" ]; then
		echo "Dashboard widget is installed ... removing."
		sudo rm -rf "/Library/Widgets/My Endpoint Protector.wdgt"
	else
		echo "Dashboard widget is not installed."
	fi
fi

# remove any launch agents (EppBasicNotifier)
sudo rm -f /Library/LaunchAgents/com.cososys.eppbasic.notifier.plist
sudo rm -f /Library/LaunchAgents/com.cososys.epp.notifier.plist
# remove symbolic links in the /Applications directory
sudo rm -f /Applications/EndpointProtectorBasic.app

# is the Notifier running?
val=`ps axc | grep -c EppBasicNotifier`
if [ $val -ge "1" ]; then
	echo "Killing the Endpoint Protector Basic notifier ..."
	sudo killall -TERM EppBasicNotifier
fi
val=`ps axc | grep -c EppNotifier`
if [ $val -ge "1" ]; then
	echo "Killing the Endpoint Protector Basic notifier ..."
	sudo killall -TERM EppNotifier
fi

# is the Endpoint Protector Basic Settings running?
val=`ps axc | grep -c EndpointProtectorBasic`
if [ $val -ge "1" ]; then
	echo "Killing the Endpoint Protector Basic Settings ..."
	sudo killall -TERM EndpointProtectorBasic
fi
val=`ps axc | grep -c USBLockdown`
if [ $val -ge "1" ]; then
	echo "Killing the USBLockdown Settings ..."
	sudo killall -TERM USBLockdown
fi


# restore the permissions for the WebCam (iSight) related files
WEBCAM_FILES=(
    "/System/Library/QuickTime/QuickTimeUSBVDCDigitizer.component/Contents/MacOS/QuickTimeUSBVDCDigitizer" \
    "/System/Library/PrivateFrameworks/CoreMediaIOServicesPrivate.framework/Versions/A/Resources/VDC.plugin/Contents/MacOS/VDC" \
    "/System/Library/PrivateFrameworks/CoreMediaIOServices.framework/Versions/A/Resources/VDC.plugin/Contents/MacOS/VDC" \
)

for i in "${WEBCAM_FILES[@]}"
do
if [ -f $i ]; then
    sudo chmod a+r,a+x $i
fi
done

# restore the permissions for the iTunes mobile device sync related files
# sudo chmod a+x /System/Library/PrivateFrameworks/MobileDevice.framework/Versions/A/Resources/usbmuxd
val=`sudo /bin/launchctl list | grep -c com.apple.usbmuxd`
if [ $val -eq "0" ]; then
    sudo /bin/launchctl load /System/Library/LaunchDaemons/com.apple.usbmuxd.plist	
fi

# restore full printing rights to all the printers
echo "Restoring printing permissions ..."
for i in `sudo lpstat -p | cut -d " " -f2`
do
sudo lpadmin -p $i -u allow:all
done

# remove the receipts
RECEIPT_FILES=(
    "/Library/Receipts/EndpointProtectorClient.debug.pkg" \
    "/Library/Receipts/EndpointProtectorClient.pkg" \
    "/Library/Receipts/MyEndpointProtectorClient.debug.pkg" \
    "/Library/Receipts/MyEndpointProtectorClient.pkg" \
)

for i in "${RECEIPT_FILES[@]}"
do
if [ -d $i ]; then
    sudo rm -r $i
fi
done

# Finally cleanup the temporary files
EPP_TEMP_FILES=(
    "/tmp/eppclient.lock" \
    "/tmp/epp-srv201f0dd30" \
    "/tmp/epp-zc239fd3" \
    "/tmp/epp-install.log" \
    "/tmp/epp-zc23.*"
)

for i in "${EPP_TEMP_FILES[@]}"
do
    sudo rm -f $i
done
